# Workflows

A "workflow" is a record of the commands and parameters you used to create a data model.
For complicated data analysis tasks, looking at the workflow will help you remember what
you did.

## Built-in Workflow Viewer

`himena-builtins` subpackage provides a built-in workflow viewer. You can view the
workflow of a sub-window
